# Internal Server Error

Most likely this is caused by an import error within Django due to an incomplete setup of your django project.

Please look into your error logs for more details.

Have you installed the database binding module?

If you made your own customizations - have you forgotten to install some dependency module? Please note that dependency modules may have their own dependencies, etc, and they should also be satisfied.

If you need further assistance, please email at support@askbot.com, post your question at AskBot Support Forum or call at +1-301-747-1533 (US).